
#ifndef PDFOUTLINE_H
#define PDFOUTLINE_H

#include "PDF.h"
#include "mustd.h"

class PDF;
/// PDFOutline class provides an interface to traverse outline tree
/// Using the goto functions below, you manipulate which node this object is looking
/// at in the tree.  Because the pointers are only one direction, to go back you need to
/// go back to root and start again.
class PDFOutline
{
public:
    /// PDFOutline()
    /// Constructor takes the PDF for which the outline belongs
    PDFOutline(PDF *parent);
    ~PDFOutline();

    /// loadfailure()  
    /// Returns true if there was a failure
    bool loadfailure();

    /// HasNextSibling()
    /// Returns true if there is a "next" element on this level of the outline tree
    bool HasNextSibling();
    /// HasChild()
    /// Returns true if there is a child element to this item of the outline
    bool HasChild();

    /// GetCurrentNodeText()
    /// Returns the string associated with this node of the outline tree
    char *GetCurrentNodeText();
    /// GetCurrentNodeLinkPageNumber()
    /// Returns the integer page number associated with the link for this outline element
    int     GetCurrentNodeLinkPageNumber();

    /// GotoNextSibling()
    /// Moves the outline object to the next sibling object
    void GotoNextSibling();
    /// Moves the outline object to the child of this node
    void GotoChild();
    /// Moves the object back to the root of the tree.
    void GotoRoot();

private:
    PDF *mParent;
    pdf_outline *mOutlineRoot;
    pdf_outline *location;    
};

#endif
